; Scopes

[
  (class_declaration)
  (function_declaration)
] @local.scope

; Definitions

(type_parameter
  (type_identifier) @local.definition.type.parameter)

; References

(type_identifier) @local.reference
